pub struct QualificationOutcome { /* private fields */ }Expand description
Complete validated evidence plus a separately enforceable performance verdict.
Implementations
Sourceimpl QualificationOutcome
impl QualificationOutcome
Sourcepub fn jsonl(&self) -> &str
pub fn jsonl(&self) -> &str
Returns the validated JSONL payload. Persist it before enforcing the gate.
Sourcepub fn regressions(&self) -> &[Regression]
pub fn regressions(&self) -> &[Regression]
Returns observed production-selection regressions.
Sourcepub fn require_pass(&self) -> Result<(), RegressionGateError>
pub fn require_pass(&self) -> Result<(), RegressionGateError>
Enforces the performance gate after evidence has been persisted.